# coding: utf-8

# flake8: noqa

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.0"

# import apis into sdk package
from onboarding_buddy_client.api.batch_api import BatchApi
from onboarding_buddy_client.api.file_api import FileApi
from onboarding_buddy_client.api.sanctions_api import SanctionsApi
from onboarding_buddy_client.api.validation_api import ValidationApi

# import ApiClient
from onboarding_buddy_client.api_response import ApiResponse
from onboarding_buddy_client.api_client import ApiClient
from onboarding_buddy_client.configuration import Configuration
from onboarding_buddy_client.exceptions import OpenApiException
from onboarding_buddy_client.exceptions import ApiTypeError
from onboarding_buddy_client.exceptions import ApiValueError
from onboarding_buddy_client.exceptions import ApiKeyError
from onboarding_buddy_client.exceptions import ApiAttributeError
from onboarding_buddy_client.exceptions import ApiException

# import models into sdk package
from onboarding_buddy_client.models.aircraft_sanction_record_m import AircraftSanctionRecordM
from onboarding_buddy_client.models.aircraft_sanctions_check_request_m import AircraftSanctionsCheckRequestM
from onboarding_buddy_client.models.aircraft_sanctions_check_response_m import AircraftSanctionsCheckResponseM
from onboarding_buddy_client.models.browser_get_batch_response_m import BrowserGetBatchResponseM
from onboarding_buddy_client.models.browser_request_m import BrowserRequestM
from onboarding_buddy_client.models.browser_response_m import BrowserResponseM
from onboarding_buddy_client.models.browser_result_m import BrowserResultM
from onboarding_buddy_client.models.browser_submit_batch_request_m import BrowserSubmitBatchRequestM
from onboarding_buddy_client.models.crypto_wallet_sanctions_check_request_m import CryptoWalletSanctionsCheckRequestM
from onboarding_buddy_client.models.crypto_wallet_sanctions_check_response_m import CryptoWalletSanctionsCheckResponseM
from onboarding_buddy_client.models.digital_currency_address_m import DigitalCurrencyAddressM
from onboarding_buddy_client.models.email_address_get_batch_response_m import EmailAddressGetBatchResponseM
from onboarding_buddy_client.models.email_address_request_m import EmailAddressRequestM
from onboarding_buddy_client.models.email_address_response_m import EmailAddressResponseM
from onboarding_buddy_client.models.email_address_result_m import EmailAddressResultM
from onboarding_buddy_client.models.email_address_submit_batch_request_m import EmailAddressSubmitBatchRequestM
from onboarding_buddy_client.models.email_entity_record_m import EmailEntityRecordM
from onboarding_buddy_client.models.email_individual_record_m import EmailIndividualRecordM
from onboarding_buddy_client.models.email_sanction_record_m import EmailSanctionRecordM
from onboarding_buddy_client.models.entity_sanctions_check_request_m import EntitySanctionsCheckRequestM
from onboarding_buddy_client.models.entity_sanctions_check_response_m import EntitySanctionsCheckResponseM
from onboarding_buddy_client.models.file_container_m import FileContainerM
from onboarding_buddy_client.models.file_record_list_response_m import FileRecordListResponseM
from onboarding_buddy_client.models.file_record_m import FileRecordM
from onboarding_buddy_client.models.file_record_meta_data_m import FileRecordMetaDataM
from onboarding_buddy_client.models.file_record_response_m import FileRecordResponseM
from onboarding_buddy_client.models.file_upload_response_m import FileUploadResponseM
from onboarding_buddy_client.models.individual_address_m import IndividualAddressM
from onboarding_buddy_client.models.individual_alias_m import IndividualAliasM
from onboarding_buddy_client.models.individual_sanction_record_m import IndividualSanctionRecordM
from onboarding_buddy_client.models.individual_sanctions_check_request_m import IndividualSanctionsCheckRequestM
from onboarding_buddy_client.models.individual_sanctions_check_response_m import IndividualSanctionsCheckResponseM
from onboarding_buddy_client.models.ip_address_get_batch_response_m import IpAddressGetBatchResponseM
from onboarding_buddy_client.models.ip_address_request_m import IpAddressRequestM
from onboarding_buddy_client.models.ip_address_response_m import IpAddressResponseM
from onboarding_buddy_client.models.ip_address_result_m import IpAddressResultM
from onboarding_buddy_client.models.ip_address_submit_batch_request_m import IpAddressSubmitBatchRequestM
from onboarding_buddy_client.models.mobile_number_get_batch_response_m import MobileNumberGetBatchResponseM
from onboarding_buddy_client.models.mobile_number_m import MobileNumberM
from onboarding_buddy_client.models.mobile_number_request_m import MobileNumberRequestM
from onboarding_buddy_client.models.mobile_number_response_m import MobileNumberResponseM
from onboarding_buddy_client.models.mobile_number_result_m import MobileNumberResultM
from onboarding_buddy_client.models.mobile_number_submit_batch_request_m import MobileNumberSubmitBatchRequestM
from onboarding_buddy_client.models.other_sanction_record_m import OtherSanctionRecordM
from onboarding_buddy_client.models.poll_batch_response_m import PollBatchResponseM
from onboarding_buddy_client.models.rag_query_request_m import RagQueryRequestM
from onboarding_buddy_client.models.rag_query_response_m import RagQueryResponseM
from onboarding_buddy_client.models.search_file_record_m import SearchFileRecordM
from onboarding_buddy_client.models.search_file_request_m import SearchFileRequestM
from onboarding_buddy_client.models.search_file_response_m import SearchFileResponseM
from onboarding_buddy_client.models.submit_batch_response_m import SubmitBatchResponseM
from onboarding_buddy_client.models.vessel_sanctions_check_request_m import VesselSanctionsCheckRequestM
from onboarding_buddy_client.models.vessel_sanctions_check_response_m import VesselSanctionsCheckResponseM



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.file_record_list_response_m import FileRecordListResponseM

class TestFileRecordListResponseM(unittest.TestCase):
    """FileRecordListResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileRecordListResponseM:
        """Test FileRecordListResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileRecordListResponseM`
        """
        model = FileRecordListResponseM()
        if include_optional:
            return FileRecordListResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                file_records = [
                    onboarding_buddy_client.models.file_record_m.FileRecordM(
                        global_id = '', 
                        organisation_global_id = '', 
                        application_global_id = '', 
                        file_name = '', 
                        mime_type = '', 
                        origin_type = '', 
                        original_file_name = '', 
                        file_size = 56, 
                        file_status = '', 
                        title = '', 
                        description = '', 
                        tags = '', 
                        reasoning = '', 
                        created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return FileRecordListResponseM(
        )
        """

    def testFileRecordListResponseM(self):
        """Test FileRecordListResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.file_upload_response_m import FileUploadResponseM

class TestFileUploadResponseM(unittest.TestCase):
    """FileUploadResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileUploadResponseM:
        """Test FileUploadResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileUploadResponseM`
        """
        model = FileUploadResponseM()
        if include_optional:
            return FileUploadResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                global_id = '',
                organisation_global_id = '',
                application_global_id = '',
                file_name = '',
                mime_type = '',
                file_size = 56,
                file_status = '',
                active = True
            )
        else:
            return FileUploadResponseM(
        )
        """

    def testFileUploadResponseM(self):
        """Test FileUploadResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class IpAddressResultM(BaseModel):
    """
    IpAddressResultM
    """ # noqa: E501
    ip_address: Optional[StrictStr] = Field(default=None, alias="ipAddress")
    iso_code: Optional[StrictStr] = Field(default=None, alias="isoCode")
    country: Optional[StrictStr] = None
    asn: Optional[StrictStr] = None
    asn_organization: Optional[StrictStr] = Field(default=None, alias="asnOrganization")
    isp: Optional[StrictStr] = None
    threat: Optional[StrictStr] = None
    risk_level: Optional[StrictStr] = Field(default=None, alias="riskLevel")
    is_tor_address: Optional[StrictBool] = Field(default=None, alias="isTorAddress")
    is_vpn_address: Optional[StrictBool] = Field(default=None, alias="isVpnAddress")
    check_status: Optional[StrictStr] = Field(default=None, alias="checkStatus")
    __properties: ClassVar[List[str]] = ["ipAddress", "isoCode", "country", "asn", "asnOrganization", "isp", "threat", "riskLevel", "isTorAddress", "isVpnAddress", "checkStatus"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IpAddressResultM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ip_address (nullable) is None
        # and model_fields_set contains the field
        if self.ip_address is None and "ip_address" in self.model_fields_set:
            _dict['ipAddress'] = None

        # set to None if iso_code (nullable) is None
        # and model_fields_set contains the field
        if self.iso_code is None and "iso_code" in self.model_fields_set:
            _dict['isoCode'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if asn (nullable) is None
        # and model_fields_set contains the field
        if self.asn is None and "asn" in self.model_fields_set:
            _dict['asn'] = None

        # set to None if asn_organization (nullable) is None
        # and model_fields_set contains the field
        if self.asn_organization is None and "asn_organization" in self.model_fields_set:
            _dict['asnOrganization'] = None

        # set to None if isp (nullable) is None
        # and model_fields_set contains the field
        if self.isp is None and "isp" in self.model_fields_set:
            _dict['isp'] = None

        # set to None if threat (nullable) is None
        # and model_fields_set contains the field
        if self.threat is None and "threat" in self.model_fields_set:
            _dict['threat'] = None

        # set to None if risk_level (nullable) is None
        # and model_fields_set contains the field
        if self.risk_level is None and "risk_level" in self.model_fields_set:
            _dict['riskLevel'] = None

        # set to None if check_status (nullable) is None
        # and model_fields_set contains the field
        if self.check_status is None and "check_status" in self.model_fields_set:
            _dict['checkStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IpAddressResultM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ipAddress": obj.get("ipAddress"),
            "isoCode": obj.get("isoCode"),
            "country": obj.get("country"),
            "asn": obj.get("asn"),
            "asnOrganization": obj.get("asnOrganization"),
            "isp": obj.get("isp"),
            "threat": obj.get("threat"),
            "riskLevel": obj.get("riskLevel"),
            "isTorAddress": obj.get("isTorAddress"),
            "isVpnAddress": obj.get("isVpnAddress"),
            "checkStatus": obj.get("checkStatus")
        })
        return _obj





# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.aircraft_sanctions_check_response_m import AircraftSanctionsCheckResponseM

class TestAircraftSanctionsCheckResponseM(unittest.TestCase):
    """AircraftSanctionsCheckResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AircraftSanctionsCheckResponseM:
        """Test AircraftSanctionsCheckResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AircraftSanctionsCheckResponseM`
        """
        model = AircraftSanctionsCheckResponseM()
        if include_optional:
            return AircraftSanctionsCheckResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                matched = True,
                match = [
                    onboarding_buddy_client.models.aircraft_sanction_record_m.AircraftSanctionRecordM(
                        full_name = '', 
                        program = '', 
                        manufacture_date = '', 
                        model = '', 
                        operator = '', 
                        manufacturer_serial_number = '', 
                        tail_number = '', 
                        construction_number = '', 
                        previous_tail_number = '', 
                        mode_s_transponder_code = '', 
                        serial_identification = '', 
                        additional_info = [
                            ''
                            ], 
                        alias_list = [
                            onboarding_buddy_client.models.individual_alias_m.IndividualAliasM(
                                full_name = '', 
                                first_name = '', 
                                last_name = '', 
                                remarks = '', )
                            ], 
                        address_list = [
                            onboarding_buddy_client.models.individual_address_m.IndividualAddressM(
                                address = '', 
                                city_state_province_postal_code = '', 
                                country = '', 
                                address_remarks = '', )
                            ], 
                        nationality = '', 
                        linked_to = '', 
                        secondary_sanctions_risk = '', 
                        also_known_as = [
                            ''
                            ], 
                        linked_individuals = [
                            onboarding_buddy_client.models.email_individual_record_m.EmailIndividualRecordM(
                                full_name = '', 
                                first_name = '', 
                                last_name = '', 
                                program = '', 
                                title = '', 
                                nationality = '', 
                                gender = '', 
                                linked_to = '', 
                                secondary_sanctions_risk = '', 
                                digital_currency_address = [
                                    onboarding_buddy_client.models.digital_currency_address_m.DigitalCurrencyAddressM(
                                        instrument = '', 
                                        address = '', )
                                    ], 
                                websites = [
                                    ''
                                    ], 
                                email_address = [
                                    ''
                                    ], )
                            ], 
                        linked_entity = [
                            onboarding_buddy_client.models.other_sanction_record_m.OtherSanctionRecordM(
                                full_name = '', 
                                program = '', 
                                title = '', 
                                nationality = '', 
                                linked_to = '', 
                                place_of_birth = '', 
                                passport = '', 
                                citizen = '', 
                                national_id_number = '', 
                                secondary_sanctions_risk = '', 
                                call_sign = '', 
                                vessel_type = '', 
                                tonnage = '', 
                                grt = '', 
                                vessel_flag = '', 
                                vessel_owner = '', )
                            ], )
                    ]
            )
        else:
            return AircraftSanctionsCheckResponseM(
        )
        """

    def testAircraftSanctionsCheckResponseM(self):
        """Test AircraftSanctionsCheckResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from onboarding_buddy_client.models.email_individual_record_m import EmailIndividualRecordM
from onboarding_buddy_client.models.individual_alias_m import IndividualAliasM
from typing import Optional, Set
from typing_extensions import Self

class EmailEntityRecordM(BaseModel):
    """
    EmailEntityRecordM
    """ # noqa: E501
    full_name: Optional[StrictStr] = Field(default=None, alias="fullName")
    program: Optional[StrictStr] = None
    additional_info: Optional[List[StrictStr]] = Field(default=None, alias="additionalInfo")
    alias_list: Optional[List[IndividualAliasM]] = Field(default=None, alias="aliasList")
    linked_to: Optional[StrictStr] = Field(default=None, alias="linkedTo")
    secondary_sanctions_risk: Optional[StrictStr] = Field(default=None, alias="secondarySanctionsRisk")
    websites: Optional[List[StrictStr]] = None
    email_address: Optional[List[StrictStr]] = Field(default=None, alias="emailAddress")
    also_known_as: Optional[List[StrictStr]] = Field(default=None, alias="alsoKnownAs")
    linked_individuals: Optional[List[EmailIndividualRecordM]] = Field(default=None, alias="linkedIndividuals")
    linked_entity: Optional[List[EmailEntityRecordM]] = Field(default=None, alias="linkedEntity")
    __properties: ClassVar[List[str]] = ["fullName", "program", "additionalInfo", "aliasList", "linkedTo", "secondarySanctionsRisk", "websites", "emailAddress", "alsoKnownAs", "linkedIndividuals", "linkedEntity"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmailEntityRecordM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in alias_list (list)
        _items = []
        if self.alias_list:
            for _item_alias_list in self.alias_list:
                if _item_alias_list:
                    _items.append(_item_alias_list.to_dict())
            _dict['aliasList'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in linked_individuals (list)
        _items = []
        if self.linked_individuals:
            for _item_linked_individuals in self.linked_individuals:
                if _item_linked_individuals:
                    _items.append(_item_linked_individuals.to_dict())
            _dict['linkedIndividuals'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in linked_entity (list)
        _items = []
        if self.linked_entity:
            for _item_linked_entity in self.linked_entity:
                if _item_linked_entity:
                    _items.append(_item_linked_entity.to_dict())
            _dict['linkedEntity'] = _items
        # set to None if full_name (nullable) is None
        # and model_fields_set contains the field
        if self.full_name is None and "full_name" in self.model_fields_set:
            _dict['fullName'] = None

        # set to None if program (nullable) is None
        # and model_fields_set contains the field
        if self.program is None and "program" in self.model_fields_set:
            _dict['program'] = None

        # set to None if additional_info (nullable) is None
        # and model_fields_set contains the field
        if self.additional_info is None and "additional_info" in self.model_fields_set:
            _dict['additionalInfo'] = None

        # set to None if alias_list (nullable) is None
        # and model_fields_set contains the field
        if self.alias_list is None and "alias_list" in self.model_fields_set:
            _dict['aliasList'] = None

        # set to None if linked_to (nullable) is None
        # and model_fields_set contains the field
        if self.linked_to is None and "linked_to" in self.model_fields_set:
            _dict['linkedTo'] = None

        # set to None if secondary_sanctions_risk (nullable) is None
        # and model_fields_set contains the field
        if self.secondary_sanctions_risk is None and "secondary_sanctions_risk" in self.model_fields_set:
            _dict['secondarySanctionsRisk'] = None

        # set to None if websites (nullable) is None
        # and model_fields_set contains the field
        if self.websites is None and "websites" in self.model_fields_set:
            _dict['websites'] = None

        # set to None if email_address (nullable) is None
        # and model_fields_set contains the field
        if self.email_address is None and "email_address" in self.model_fields_set:
            _dict['emailAddress'] = None

        # set to None if also_known_as (nullable) is None
        # and model_fields_set contains the field
        if self.also_known_as is None and "also_known_as" in self.model_fields_set:
            _dict['alsoKnownAs'] = None

        # set to None if linked_individuals (nullable) is None
        # and model_fields_set contains the field
        if self.linked_individuals is None and "linked_individuals" in self.model_fields_set:
            _dict['linkedIndividuals'] = None

        # set to None if linked_entity (nullable) is None
        # and model_fields_set contains the field
        if self.linked_entity is None and "linked_entity" in self.model_fields_set:
            _dict['linkedEntity'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmailEntityRecordM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "fullName": obj.get("fullName"),
            "program": obj.get("program"),
            "additionalInfo": obj.get("additionalInfo"),
            "aliasList": [IndividualAliasM.from_dict(_item) for _item in obj["aliasList"]] if obj.get("aliasList") is not None else None,
            "linkedTo": obj.get("linkedTo"),
            "secondarySanctionsRisk": obj.get("secondarySanctionsRisk"),
            "websites": obj.get("websites"),
            "emailAddress": obj.get("emailAddress"),
            "alsoKnownAs": obj.get("alsoKnownAs"),
            "linkedIndividuals": [EmailIndividualRecordM.from_dict(_item) for _item in obj["linkedIndividuals"]] if obj.get("linkedIndividuals") is not None else None,
            "linkedEntity": [EmailEntityRecordM.from_dict(_item) for _item in obj["linkedEntity"]] if obj.get("linkedEntity") is not None else None
        })
        return _obj

# TODO: Rewrite to not use raise_errors
EmailEntityRecordM.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.search_file_record_m import SearchFileRecordM

class TestSearchFileRecordM(unittest.TestCase):
    """SearchFileRecordM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFileRecordM:
        """Test SearchFileRecordM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFileRecordM`
        """
        model = SearchFileRecordM()
        if include_optional:
            return SearchFileRecordM(
                global_id = '',
                organisation_global_id = '',
                application_global_id = '',
                file_name = '',
                mime_type = '',
                origin_type = '',
                original_file_name = '',
                file_size = 56,
                file_status = '',
                title = '',
                description = '',
                tags = '',
                reasoning = '',
                created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                distance = 1.337,
                document = '',
                meta_data = onboarding_buddy_client.models.file_record_meta_data_m.FileRecordMetaDataM(
                    chunk_index = 56, 
                    document = '', 
                    source = '', )
            )
        else:
            return SearchFileRecordM(
        )
        """

    def testSearchFileRecordM(self):
        """Test SearchFileRecordM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EmailAddressResultM(BaseModel):
    """
    EmailAddressResultM
    """ # noqa: E501
    email_address: Optional[StrictStr] = Field(default=None, alias="emailAddress")
    email_status: Optional[StrictStr] = Field(default=None, alias="emailStatus")
    free_email: Optional[StrictBool] = Field(default=None, alias="freeEmail")
    did_you_mean: Optional[StrictStr] = Field(default=None, alias="didYouMean")
    domain: Optional[StrictStr] = None
    mx_found: Optional[StrictBool] = Field(default=None, alias="mxFound")
    mx_record: Optional[StrictStr] = Field(default=None, alias="mxRecord")
    is_disposable_domain: Optional[StrictBool] = Field(default=None, alias="isDisposableDomain")
    check_status: Optional[StrictStr] = Field(default=None, alias="checkStatus")
    __properties: ClassVar[List[str]] = ["emailAddress", "emailStatus", "freeEmail", "didYouMean", "domain", "mxFound", "mxRecord", "isDisposableDomain", "checkStatus"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmailAddressResultM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if email_address (nullable) is None
        # and model_fields_set contains the field
        if self.email_address is None and "email_address" in self.model_fields_set:
            _dict['emailAddress'] = None

        # set to None if email_status (nullable) is None
        # and model_fields_set contains the field
        if self.email_status is None and "email_status" in self.model_fields_set:
            _dict['emailStatus'] = None

        # set to None if did_you_mean (nullable) is None
        # and model_fields_set contains the field
        if self.did_you_mean is None and "did_you_mean" in self.model_fields_set:
            _dict['didYouMean'] = None

        # set to None if domain (nullable) is None
        # and model_fields_set contains the field
        if self.domain is None and "domain" in self.model_fields_set:
            _dict['domain'] = None

        # set to None if mx_record (nullable) is None
        # and model_fields_set contains the field
        if self.mx_record is None and "mx_record" in self.model_fields_set:
            _dict['mxRecord'] = None

        # set to None if check_status (nullable) is None
        # and model_fields_set contains the field
        if self.check_status is None and "check_status" in self.model_fields_set:
            _dict['checkStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmailAddressResultM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "emailAddress": obj.get("emailAddress"),
            "emailStatus": obj.get("emailStatus"),
            "freeEmail": obj.get("freeEmail"),
            "didYouMean": obj.get("didYouMean"),
            "domain": obj.get("domain"),
            "mxFound": obj.get("mxFound"),
            "mxRecord": obj.get("mxRecord"),
            "isDisposableDomain": obj.get("isDisposableDomain"),
            "checkStatus": obj.get("checkStatus")
        })
        return _obj





# flake8: noqa

# import apis into api package
from onboarding_buddy_client.api.batch_api import BatchApi
from onboarding_buddy_client.api.file_api import FileApi
from onboarding_buddy_client.api.sanctions_api import SanctionsApi
from onboarding_buddy_client.api.validation_api import ValidationApi




# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class FileUploadResponseM(BaseModel):
    """
    FileUploadResponseM
    """ # noqa: E501
    message_id: Optional[StrictStr] = Field(default=None, alias="messageId")
    correlation_id: Optional[StrictStr] = Field(default=None, alias="correlationId")
    idempotency_key: Optional[StrictStr] = Field(default=None, alias="idempotencyKey")
    in_error: Optional[StrictBool] = Field(default=None, alias="inError")
    error_type: Optional[StrictStr] = Field(default=None, alias="errorType")
    messages: Optional[List[StrictStr]] = None
    global_id: Optional[StrictStr] = Field(default=None, alias="globalId")
    organisation_global_id: Optional[StrictStr] = Field(default=None, alias="organisationGlobalId")
    application_global_id: Optional[StrictStr] = Field(default=None, alias="applicationGlobalId")
    file_name: Optional[StrictStr] = Field(default=None, alias="fileName")
    mime_type: Optional[StrictStr] = Field(default=None, alias="mimeType")
    file_size: Optional[StrictInt] = Field(default=None, alias="fileSize")
    file_status: Optional[StrictStr] = Field(default=None, alias="fileStatus")
    active: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["messageId", "correlationId", "idempotencyKey", "inError", "errorType", "messages", "globalId", "organisationGlobalId", "applicationGlobalId", "fileName", "mimeType", "fileSize", "fileStatus", "active"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileUploadResponseM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if message_id (nullable) is None
        # and model_fields_set contains the field
        if self.message_id is None and "message_id" in self.model_fields_set:
            _dict['messageId'] = None

        # set to None if correlation_id (nullable) is None
        # and model_fields_set contains the field
        if self.correlation_id is None and "correlation_id" in self.model_fields_set:
            _dict['correlationId'] = None

        # set to None if idempotency_key (nullable) is None
        # and model_fields_set contains the field
        if self.idempotency_key is None and "idempotency_key" in self.model_fields_set:
            _dict['idempotencyKey'] = None

        # set to None if error_type (nullable) is None
        # and model_fields_set contains the field
        if self.error_type is None and "error_type" in self.model_fields_set:
            _dict['errorType'] = None

        # set to None if messages (nullable) is None
        # and model_fields_set contains the field
        if self.messages is None and "messages" in self.model_fields_set:
            _dict['messages'] = None

        # set to None if global_id (nullable) is None
        # and model_fields_set contains the field
        if self.global_id is None and "global_id" in self.model_fields_set:
            _dict['globalId'] = None

        # set to None if organisation_global_id (nullable) is None
        # and model_fields_set contains the field
        if self.organisation_global_id is None and "organisation_global_id" in self.model_fields_set:
            _dict['organisationGlobalId'] = None

        # set to None if application_global_id (nullable) is None
        # and model_fields_set contains the field
        if self.application_global_id is None and "application_global_id" in self.model_fields_set:
            _dict['applicationGlobalId'] = None

        # set to None if file_name (nullable) is None
        # and model_fields_set contains the field
        if self.file_name is None and "file_name" in self.model_fields_set:
            _dict['fileName'] = None

        # set to None if mime_type (nullable) is None
        # and model_fields_set contains the field
        if self.mime_type is None and "mime_type" in self.model_fields_set:
            _dict['mimeType'] = None

        # set to None if file_status (nullable) is None
        # and model_fields_set contains the field
        if self.file_status is None and "file_status" in self.model_fields_set:
            _dict['fileStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileUploadResponseM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "messageId": obj.get("messageId"),
            "correlationId": obj.get("correlationId"),
            "idempotencyKey": obj.get("idempotencyKey"),
            "inError": obj.get("inError"),
            "errorType": obj.get("errorType"),
            "messages": obj.get("messages"),
            "globalId": obj.get("globalId"),
            "organisationGlobalId": obj.get("organisationGlobalId"),
            "applicationGlobalId": obj.get("applicationGlobalId"),
            "fileName": obj.get("fileName"),
            "mimeType": obj.get("mimeType"),
            "fileSize": obj.get("fileSize"),
            "fileStatus": obj.get("fileStatus"),
            "active": obj.get("active")
        })
        return _obj





# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.file_api import FileApi


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileApi()

    def tearDown(self) -> None:
        pass

    def test_document_rag(self) -> None:
        """Test case for document_rag

        Document RAG
        """
        pass

    def test_download(self) -> None:
        """Test case for download

        File Download
        """
        pass

    def test_get_file_record(self) -> None:
        """Test case for get_file_record

        Get File
        """
        pass

    def test_get_file_records(self) -> None:
        """Test case for get_file_records

        Get Files
        """
        pass

    def test_search_file_records(self) -> None:
        """Test case for search_file_records

        Search Files
        """
        pass

    def test_upload(self) -> None:
        """Test case for upload

        File Upload
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing_extensions import Annotated
from onboarding_buddy_client.models.browser_get_batch_response_m import BrowserGetBatchResponseM
from onboarding_buddy_client.models.browser_submit_batch_request_m import BrowserSubmitBatchRequestM
from onboarding_buddy_client.models.email_address_get_batch_response_m import EmailAddressGetBatchResponseM
from onboarding_buddy_client.models.email_address_submit_batch_request_m import EmailAddressSubmitBatchRequestM
from onboarding_buddy_client.models.ip_address_get_batch_response_m import IpAddressGetBatchResponseM
from onboarding_buddy_client.models.ip_address_submit_batch_request_m import IpAddressSubmitBatchRequestM
from onboarding_buddy_client.models.mobile_number_get_batch_response_m import MobileNumberGetBatchResponseM
from onboarding_buddy_client.models.mobile_number_submit_batch_request_m import MobileNumberSubmitBatchRequestM
from onboarding_buddy_client.models.poll_batch_response_m import PollBatchResponseM
from onboarding_buddy_client.models.submit_batch_response_m import SubmitBatchResponseM

from onboarding_buddy_client.api_client import ApiClient, RequestSerialized
from onboarding_buddy_client.api_response import ApiResponse
from onboarding_buddy_client.rest import RESTResponseType


class BatchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_browser_batch(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrowserGetBatchResponseM:
        """Get the results for a batch - browser

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_browser_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrowserGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_browser_batch_with_http_info(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrowserGetBatchResponseM]:
        """Get the results for a batch - browser

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_browser_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrowserGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_browser_batch_without_preload_content(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the results for a batch - browser

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_browser_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrowserGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_browser_batch_serialize(
        self,
        batch_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batchId'] = batch_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/validation-service/batch/browser/{batchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_emailaddress_batch(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EmailAddressGetBatchResponseM:
        """Get the results for a batch - email address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_emailaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EmailAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_emailaddress_batch_with_http_info(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EmailAddressGetBatchResponseM]:
        """Get the results for a batch - email address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_emailaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EmailAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_emailaddress_batch_without_preload_content(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the results for a batch - email address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_emailaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EmailAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_emailaddress_batch_serialize(
        self,
        batch_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batchId'] = batch_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/validation-service/batch/email-address/{batchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_ipaddress_batch(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> IpAddressGetBatchResponseM:
        """Get the results for a batch - ip address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_ipaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IpAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_ipaddress_batch_with_http_info(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[IpAddressGetBatchResponseM]:
        """Get the results for a batch - ip address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_ipaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IpAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_ipaddress_batch_without_preload_content(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the results for a batch - ip address

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_ipaddress_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IpAddressGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_ipaddress_batch_serialize(
        self,
        batch_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batchId'] = batch_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/validation-service/batch/ip-address/{batchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_mobilenumber_batch(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MobileNumberGetBatchResponseM:
        """Get the results for a batch - mobile number

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_mobilenumber_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MobileNumberGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_mobilenumber_batch_with_http_info(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MobileNumberGetBatchResponseM]:
        """Get the results for a batch - mobile number

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_mobilenumber_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MobileNumberGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_mobilenumber_batch_without_preload_content(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the results for a batch - mobile number

        This action returns the batch results response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_mobilenumber_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MobileNumberGetBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_mobilenumber_batch_serialize(
        self,
        batch_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batchId'] = batch_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/validation-service/batch/mobile/{batchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def poll_batch(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PollBatchResponseM:
        """Poll the state of a batch submitted for processing

        This action returns the batch poll response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PollBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def poll_batch_with_http_info(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PollBatchResponseM]:
        """Poll the state of a batch submitted for processing

        This action returns the batch poll response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PollBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def poll_batch_without_preload_content(
        self,
        batch_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Poll the state of a batch submitted for processing

        This action returns the batch poll response

        :param batch_id: (required)
        :type batch_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_batch_serialize(
            batch_id=batch_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PollBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _poll_batch_serialize(
        self,
        batch_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batchId'] = batch_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/validation-service/batch/poll/{batchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def submit_browser_batch(
        self,
        browser_submit_batch_request_m: Annotated[BrowserSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SubmitBatchResponseM:
        """Perform browser validation for a batch of values

        This action returns the batch validation response

        :param browser_submit_batch_request_m: The request payload (required)
        :type browser_submit_batch_request_m: BrowserSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_browser_batch_serialize(
            browser_submit_batch_request_m=browser_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def submit_browser_batch_with_http_info(
        self,
        browser_submit_batch_request_m: Annotated[BrowserSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SubmitBatchResponseM]:
        """Perform browser validation for a batch of values

        This action returns the batch validation response

        :param browser_submit_batch_request_m: The request payload (required)
        :type browser_submit_batch_request_m: BrowserSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_browser_batch_serialize(
            browser_submit_batch_request_m=browser_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def submit_browser_batch_without_preload_content(
        self,
        browser_submit_batch_request_m: Annotated[BrowserSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform browser validation for a batch of values

        This action returns the batch validation response

        :param browser_submit_batch_request_m: The request payload (required)
        :type browser_submit_batch_request_m: BrowserSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_browser_batch_serialize(
            browser_submit_batch_request_m=browser_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _submit_browser_batch_serialize(
        self,
        browser_submit_batch_request_m,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if browser_submit_batch_request_m is not None:
            _body_params = browser_submit_batch_request_m


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/validation-service/batch/browser',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def submit_emailaddress_batch(
        self,
        email_address_submit_batch_request_m: Annotated[EmailAddressSubmitBatchRequestM, Field(description="An instance of the EmailAddressSubmitBatchRequestM model")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SubmitBatchResponseM:
        """Perform email address validation for a batch of values

        This action returns the batch validation response

        :param email_address_submit_batch_request_m: An instance of the EmailAddressSubmitBatchRequestM model (required)
        :type email_address_submit_batch_request_m: EmailAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_emailaddress_batch_serialize(
            email_address_submit_batch_request_m=email_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def submit_emailaddress_batch_with_http_info(
        self,
        email_address_submit_batch_request_m: Annotated[EmailAddressSubmitBatchRequestM, Field(description="An instance of the EmailAddressSubmitBatchRequestM model")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SubmitBatchResponseM]:
        """Perform email address validation for a batch of values

        This action returns the batch validation response

        :param email_address_submit_batch_request_m: An instance of the EmailAddressSubmitBatchRequestM model (required)
        :type email_address_submit_batch_request_m: EmailAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_emailaddress_batch_serialize(
            email_address_submit_batch_request_m=email_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def submit_emailaddress_batch_without_preload_content(
        self,
        email_address_submit_batch_request_m: Annotated[EmailAddressSubmitBatchRequestM, Field(description="An instance of the EmailAddressSubmitBatchRequestM model")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform email address validation for a batch of values

        This action returns the batch validation response

        :param email_address_submit_batch_request_m: An instance of the EmailAddressSubmitBatchRequestM model (required)
        :type email_address_submit_batch_request_m: EmailAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_emailaddress_batch_serialize(
            email_address_submit_batch_request_m=email_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _submit_emailaddress_batch_serialize(
        self,
        email_address_submit_batch_request_m,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if email_address_submit_batch_request_m is not None:
            _body_params = email_address_submit_batch_request_m


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/validation-service/batch/email-address',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def submit_ipaddress_batch(
        self,
        ip_address_submit_batch_request_m: Annotated[IpAddressSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SubmitBatchResponseM:
        """Perform ip address validation for a batch of values

        This action returns the batch validation response

        :param ip_address_submit_batch_request_m: The request payload (required)
        :type ip_address_submit_batch_request_m: IpAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_ipaddress_batch_serialize(
            ip_address_submit_batch_request_m=ip_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def submit_ipaddress_batch_with_http_info(
        self,
        ip_address_submit_batch_request_m: Annotated[IpAddressSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SubmitBatchResponseM]:
        """Perform ip address validation for a batch of values

        This action returns the batch validation response

        :param ip_address_submit_batch_request_m: The request payload (required)
        :type ip_address_submit_batch_request_m: IpAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_ipaddress_batch_serialize(
            ip_address_submit_batch_request_m=ip_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def submit_ipaddress_batch_without_preload_content(
        self,
        ip_address_submit_batch_request_m: Annotated[IpAddressSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform ip address validation for a batch of values

        This action returns the batch validation response

        :param ip_address_submit_batch_request_m: The request payload (required)
        :type ip_address_submit_batch_request_m: IpAddressSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_ipaddress_batch_serialize(
            ip_address_submit_batch_request_m=ip_address_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _submit_ipaddress_batch_serialize(
        self,
        ip_address_submit_batch_request_m,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if ip_address_submit_batch_request_m is not None:
            _body_params = ip_address_submit_batch_request_m


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/validation-service/batch/ip-address',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def submit_mobilenumber_batch(
        self,
        mobile_number_submit_batch_request_m: Annotated[MobileNumberSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SubmitBatchResponseM:
        """Perform mobile number validation for a batch of values

        This action returns the batch validation response

        :param mobile_number_submit_batch_request_m: The request payload (required)
        :type mobile_number_submit_batch_request_m: MobileNumberSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_mobilenumber_batch_serialize(
            mobile_number_submit_batch_request_m=mobile_number_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def submit_mobilenumber_batch_with_http_info(
        self,
        mobile_number_submit_batch_request_m: Annotated[MobileNumberSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SubmitBatchResponseM]:
        """Perform mobile number validation for a batch of values

        This action returns the batch validation response

        :param mobile_number_submit_batch_request_m: The request payload (required)
        :type mobile_number_submit_batch_request_m: MobileNumberSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_mobilenumber_batch_serialize(
            mobile_number_submit_batch_request_m=mobile_number_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def submit_mobilenumber_batch_without_preload_content(
        self,
        mobile_number_submit_batch_request_m: Annotated[MobileNumberSubmitBatchRequestM, Field(description="The request payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform mobile number validation for a batch of values

        This action returns the batch validation response

        :param mobile_number_submit_batch_request_m: The request payload (required)
        :type mobile_number_submit_batch_request_m: MobileNumberSubmitBatchRequestM
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_mobilenumber_batch_serialize(
            mobile_number_submit_batch_request_m=mobile_number_submit_batch_request_m,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitBatchResponseM",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _submit_mobilenumber_batch_serialize(
        self,
        mobile_number_submit_batch_request_m,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if mobile_number_submit_batch_request_m is not None:
            _body_params = mobile_number_submit_batch_request_m


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey', 
            'AppKey', 
            'ApiSecret'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/validation-service/batch/mobile',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.batch_api import BatchApi


class TestBatchApi(unittest.TestCase):
    """BatchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BatchApi()

    def tearDown(self) -> None:
        pass

    def test_get_browser_batch(self) -> None:
        """Test case for get_browser_batch

        Get the results for a batch - browser
        """
        pass

    def test_get_emailaddress_batch(self) -> None:
        """Test case for get_emailaddress_batch

        Get the results for a batch - email address
        """
        pass

    def test_get_ipaddress_batch(self) -> None:
        """Test case for get_ipaddress_batch

        Get the results for a batch - ip address
        """
        pass

    def test_get_mobilenumber_batch(self) -> None:
        """Test case for get_mobilenumber_batch

        Get the results for a batch - mobile number
        """
        pass

    def test_poll_batch(self) -> None:
        """Test case for poll_batch

        Poll the state of a batch submitted for processing
        """
        pass

    def test_submit_browser_batch(self) -> None:
        """Test case for submit_browser_batch

        Perform browser validation for a batch of values
        """
        pass

    def test_submit_emailaddress_batch(self) -> None:
        """Test case for submit_emailaddress_batch

        Perform email address validation for a batch of values
        """
        pass

    def test_submit_ipaddress_batch(self) -> None:
        """Test case for submit_ipaddress_batch

        Perform ip address validation for a batch of values
        """
        pass

    def test_submit_mobilenumber_batch(self) -> None:
        """Test case for submit_mobilenumber_batch

        Perform mobile number validation for a batch of values
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.individual_sanction_record_m import IndividualSanctionRecordM

class TestIndividualSanctionRecordM(unittest.TestCase):
    """IndividualSanctionRecordM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IndividualSanctionRecordM:
        """Test IndividualSanctionRecordM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IndividualSanctionRecordM`
        """
        model = IndividualSanctionRecordM()
        if include_optional:
            return IndividualSanctionRecordM(
                full_name = '',
                first_name = '',
                last_name = '',
                program = '',
                title = '',
                additional_info = [
                    ''
                    ],
                alias_list = [
                    onboarding_buddy_client.models.individual_alias_m.IndividualAliasM(
                        full_name = '', 
                        first_name = '', 
                        last_name = '', 
                        remarks = '', )
                    ],
                address_list = [
                    onboarding_buddy_client.models.individual_address_m.IndividualAddressM(
                        address = '', 
                        city_state_province_postal_code = '', 
                        country = '', 
                        address_remarks = '', )
                    ],
                date_of_birth = '',
                birth_year = '',
                nationality = '',
                gender = '',
                linked_to = '',
                place_of_birth = '',
                passport = '',
                citizen = '',
                national_id_number = '',
                secondary_sanctions_risk = '',
                digital_currency_address = [
                    onboarding_buddy_client.models.digital_currency_address_m.DigitalCurrencyAddressM(
                        instrument = '', 
                        address = '', )
                    ],
                websites = [
                    ''
                    ],
                email_address = [
                    ''
                    ],
                also_known_as = [
                    ''
                    ]
            )
        else:
            return IndividualSanctionRecordM(
        )
        """

    def testIndividualSanctionRecordM(self):
        """Test IndividualSanctionRecordM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.individual_sanctions_check_response_m import IndividualSanctionsCheckResponseM

class TestIndividualSanctionsCheckResponseM(unittest.TestCase):
    """IndividualSanctionsCheckResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IndividualSanctionsCheckResponseM:
        """Test IndividualSanctionsCheckResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IndividualSanctionsCheckResponseM`
        """
        model = IndividualSanctionsCheckResponseM()
        if include_optional:
            return IndividualSanctionsCheckResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                matched = True,
                results = [
                    onboarding_buddy_client.models.individual_sanction_record_m.IndividualSanctionRecordM(
                        full_name = '', 
                        first_name = '', 
                        last_name = '', 
                        program = '', 
                        title = '', 
                        additional_info = [
                            ''
                            ], 
                        alias_list = [
                            onboarding_buddy_client.models.individual_alias_m.IndividualAliasM(
                                full_name = '', 
                                first_name = '', 
                                last_name = '', 
                                remarks = '', )
                            ], 
                        address_list = [
                            onboarding_buddy_client.models.individual_address_m.IndividualAddressM(
                                address = '', 
                                city_state_province_postal_code = '', 
                                country = '', 
                                address_remarks = '', )
                            ], 
                        date_of_birth = '', 
                        birth_year = '', 
                        nationality = '', 
                        gender = '', 
                        linked_to = '', 
                        place_of_birth = '', 
                        passport = '', 
                        citizen = '', 
                        national_id_number = '', 
                        secondary_sanctions_risk = '', 
                        digital_currency_address = [
                            onboarding_buddy_client.models.digital_currency_address_m.DigitalCurrencyAddressM(
                                instrument = '', 
                                address = '', )
                            ], 
                        websites = [
                            ''
                            ], 
                        email_address = [
                            ''
                            ], 
                        also_known_as = [
                            ''
                            ], )
                    ]
            )
        else:
            return IndividualSanctionsCheckResponseM(
        )
        """

    def testIndividualSanctionsCheckResponseM(self):
        """Test IndividualSanctionsCheckResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class BrowserResponseM(BaseModel):
    """
    BrowserResponseM
    """ # noqa: E501
    message_id: Optional[StrictStr] = Field(default=None, alias="messageId")
    correlation_id: Optional[StrictStr] = Field(default=None, alias="correlationId")
    idempotency_key: Optional[StrictStr] = Field(default=None, alias="idempotencyKey")
    in_error: Optional[StrictBool] = Field(default=None, alias="inError")
    error_type: Optional[StrictStr] = Field(default=None, alias="errorType")
    messages: Optional[List[StrictStr]] = None
    user_agent: Optional[StrictStr] = Field(default=None, alias="userAgent")
    simple_software: Optional[StrictStr] = Field(default=None, alias="simpleSoftware")
    software: Optional[StrictStr] = None
    software_name: Optional[StrictStr] = Field(default=None, alias="softwareName")
    operating_system: Optional[StrictStr] = Field(default=None, alias="operatingSystem")
    operating_system_flavour: Optional[StrictStr] = Field(default=None, alias="operatingSystemFlavour")
    operating_system_version: Optional[StrictStr] = Field(default=None, alias="operatingSystemVersion")
    is_abusive: Optional[StrictBool] = Field(default=None, alias="isAbusive")
    check_status: Optional[StrictStr] = Field(default=None, alias="checkStatus")
    __properties: ClassVar[List[str]] = ["messageId", "correlationId", "idempotencyKey", "inError", "errorType", "messages", "userAgent", "simpleSoftware", "software", "softwareName", "operatingSystem", "operatingSystemFlavour", "operatingSystemVersion", "isAbusive", "checkStatus"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BrowserResponseM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if message_id (nullable) is None
        # and model_fields_set contains the field
        if self.message_id is None and "message_id" in self.model_fields_set:
            _dict['messageId'] = None

        # set to None if correlation_id (nullable) is None
        # and model_fields_set contains the field
        if self.correlation_id is None and "correlation_id" in self.model_fields_set:
            _dict['correlationId'] = None

        # set to None if idempotency_key (nullable) is None
        # and model_fields_set contains the field
        if self.idempotency_key is None and "idempotency_key" in self.model_fields_set:
            _dict['idempotencyKey'] = None

        # set to None if error_type (nullable) is None
        # and model_fields_set contains the field
        if self.error_type is None and "error_type" in self.model_fields_set:
            _dict['errorType'] = None

        # set to None if messages (nullable) is None
        # and model_fields_set contains the field
        if self.messages is None and "messages" in self.model_fields_set:
            _dict['messages'] = None

        # set to None if user_agent (nullable) is None
        # and model_fields_set contains the field
        if self.user_agent is None and "user_agent" in self.model_fields_set:
            _dict['userAgent'] = None

        # set to None if simple_software (nullable) is None
        # and model_fields_set contains the field
        if self.simple_software is None and "simple_software" in self.model_fields_set:
            _dict['simpleSoftware'] = None

        # set to None if software (nullable) is None
        # and model_fields_set contains the field
        if self.software is None and "software" in self.model_fields_set:
            _dict['software'] = None

        # set to None if software_name (nullable) is None
        # and model_fields_set contains the field
        if self.software_name is None and "software_name" in self.model_fields_set:
            _dict['softwareName'] = None

        # set to None if operating_system (nullable) is None
        # and model_fields_set contains the field
        if self.operating_system is None and "operating_system" in self.model_fields_set:
            _dict['operatingSystem'] = None

        # set to None if operating_system_flavour (nullable) is None
        # and model_fields_set contains the field
        if self.operating_system_flavour is None and "operating_system_flavour" in self.model_fields_set:
            _dict['operatingSystemFlavour'] = None

        # set to None if operating_system_version (nullable) is None
        # and model_fields_set contains the field
        if self.operating_system_version is None and "operating_system_version" in self.model_fields_set:
            _dict['operatingSystemVersion'] = None

        # set to None if check_status (nullable) is None
        # and model_fields_set contains the field
        if self.check_status is None and "check_status" in self.model_fields_set:
            _dict['checkStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BrowserResponseM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "messageId": obj.get("messageId"),
            "correlationId": obj.get("correlationId"),
            "idempotencyKey": obj.get("idempotencyKey"),
            "inError": obj.get("inError"),
            "errorType": obj.get("errorType"),
            "messages": obj.get("messages"),
            "userAgent": obj.get("userAgent"),
            "simpleSoftware": obj.get("simpleSoftware"),
            "software": obj.get("software"),
            "softwareName": obj.get("softwareName"),
            "operatingSystem": obj.get("operatingSystem"),
            "operatingSystemFlavour": obj.get("operatingSystemFlavour"),
            "operatingSystemVersion": obj.get("operatingSystemVersion"),
            "isAbusive": obj.get("isAbusive"),
            "checkStatus": obj.get("checkStatus")
        })
        return _obj





# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.ip_address_get_batch_response_m import IpAddressGetBatchResponseM

class TestIpAddressGetBatchResponseM(unittest.TestCase):
    """IpAddressGetBatchResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpAddressGetBatchResponseM:
        """Test IpAddressGetBatchResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpAddressGetBatchResponseM`
        """
        model = IpAddressGetBatchResponseM()
        if include_optional:
            return IpAddressGetBatchResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                batch_id = '',
                batch_status = '',
                batch_size = 56,
                batch_type = '',
                created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                processed_count = 56,
                error_count = 56,
                result_data = [
                    {"ipAddress":"18.230.227.254","isoCode":"BR","country":"Brazil","threat":"unknown","riskLevel":"1","checkStatus":"Matched"}
                    ]
            )
        else:
            return IpAddressGetBatchResponseM(
        )
        """

    def testIpAddressGetBatchResponseM(self):
        """Test IpAddressGetBatchResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.file_record_response_m import FileRecordResponseM

class TestFileRecordResponseM(unittest.TestCase):
    """FileRecordResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileRecordResponseM:
        """Test FileRecordResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileRecordResponseM`
        """
        model = FileRecordResponseM()
        if include_optional:
            return FileRecordResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                file_record = onboarding_buddy_client.models.file_record_m.FileRecordM(
                    global_id = '', 
                    organisation_global_id = '', 
                    application_global_id = '', 
                    file_name = '', 
                    mime_type = '', 
                    origin_type = '', 
                    original_file_name = '', 
                    file_size = 56, 
                    file_status = '', 
                    title = '', 
                    description = '', 
                    tags = '', 
                    reasoning = '', 
                    created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return FileRecordResponseM(
        )
        """

    def testFileRecordResponseM(self):
        """Test FileRecordResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from onboarding_buddy_client.models.email_sanction_record_m import EmailSanctionRecordM
from typing import Optional, Set
from typing_extensions import Self

class EmailAddressResponseM(BaseModel):
    """
    EmailAddressResponseM
    """ # noqa: E501
    message_id: Optional[StrictStr] = Field(default=None, alias="messageId")
    correlation_id: Optional[StrictStr] = Field(default=None, alias="correlationId")
    idempotency_key: Optional[StrictStr] = Field(default=None, alias="idempotencyKey")
    in_error: Optional[StrictBool] = Field(default=None, alias="inError")
    error_type: Optional[StrictStr] = Field(default=None, alias="errorType")
    messages: Optional[List[StrictStr]] = None
    email_address: Optional[StrictStr] = Field(default=None, alias="emailAddress")
    email_status: Optional[StrictStr] = Field(default=None, alias="emailStatus")
    free_email: Optional[StrictBool] = Field(default=None, alias="freeEmail")
    did_you_mean: Optional[StrictStr] = Field(default=None, alias="didYouMean")
    domain: Optional[StrictStr] = None
    smtp_provider: Optional[StrictStr] = Field(default=None, alias="smtpProvider")
    mx_found: Optional[StrictBool] = Field(default=None, alias="mxFound")
    mx_record: Optional[StrictStr] = Field(default=None, alias="mxRecord")
    is_disposable_domain: Optional[StrictBool] = Field(default=None, alias="isDisposableDomain")
    check_status: Optional[StrictStr] = Field(default=None, alias="checkStatus")
    sanction_record: Optional[EmailSanctionRecordM] = Field(default=None, alias="sanctionRecord")
    __properties: ClassVar[List[str]] = ["messageId", "correlationId", "idempotencyKey", "inError", "errorType", "messages", "emailAddress", "emailStatus", "freeEmail", "didYouMean", "domain", "smtpProvider", "mxFound", "mxRecord", "isDisposableDomain", "checkStatus", "sanctionRecord"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmailAddressResponseM from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of sanction_record
        if self.sanction_record:
            _dict['sanctionRecord'] = self.sanction_record.to_dict()
        # set to None if message_id (nullable) is None
        # and model_fields_set contains the field
        if self.message_id is None and "message_id" in self.model_fields_set:
            _dict['messageId'] = None

        # set to None if correlation_id (nullable) is None
        # and model_fields_set contains the field
        if self.correlation_id is None and "correlation_id" in self.model_fields_set:
            _dict['correlationId'] = None

        # set to None if idempotency_key (nullable) is None
        # and model_fields_set contains the field
        if self.idempotency_key is None and "idempotency_key" in self.model_fields_set:
            _dict['idempotencyKey'] = None

        # set to None if error_type (nullable) is None
        # and model_fields_set contains the field
        if self.error_type is None and "error_type" in self.model_fields_set:
            _dict['errorType'] = None

        # set to None if messages (nullable) is None
        # and model_fields_set contains the field
        if self.messages is None and "messages" in self.model_fields_set:
            _dict['messages'] = None

        # set to None if email_address (nullable) is None
        # and model_fields_set contains the field
        if self.email_address is None and "email_address" in self.model_fields_set:
            _dict['emailAddress'] = None

        # set to None if email_status (nullable) is None
        # and model_fields_set contains the field
        if self.email_status is None and "email_status" in self.model_fields_set:
            _dict['emailStatus'] = None

        # set to None if did_you_mean (nullable) is None
        # and model_fields_set contains the field
        if self.did_you_mean is None and "did_you_mean" in self.model_fields_set:
            _dict['didYouMean'] = None

        # set to None if domain (nullable) is None
        # and model_fields_set contains the field
        if self.domain is None and "domain" in self.model_fields_set:
            _dict['domain'] = None

        # set to None if smtp_provider (nullable) is None
        # and model_fields_set contains the field
        if self.smtp_provider is None and "smtp_provider" in self.model_fields_set:
            _dict['smtpProvider'] = None

        # set to None if mx_record (nullable) is None
        # and model_fields_set contains the field
        if self.mx_record is None and "mx_record" in self.model_fields_set:
            _dict['mxRecord'] = None

        # set to None if check_status (nullable) is None
        # and model_fields_set contains the field
        if self.check_status is None and "check_status" in self.model_fields_set:
            _dict['checkStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmailAddressResponseM from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "messageId": obj.get("messageId"),
            "correlationId": obj.get("correlationId"),
            "idempotencyKey": obj.get("idempotencyKey"),
            "inError": obj.get("inError"),
            "errorType": obj.get("errorType"),
            "messages": obj.get("messages"),
            "emailAddress": obj.get("emailAddress"),
            "emailStatus": obj.get("emailStatus"),
            "freeEmail": obj.get("freeEmail"),
            "didYouMean": obj.get("didYouMean"),
            "domain": obj.get("domain"),
            "smtpProvider": obj.get("smtpProvider"),
            "mxFound": obj.get("mxFound"),
            "mxRecord": obj.get("mxRecord"),
            "isDisposableDomain": obj.get("isDisposableDomain"),
            "checkStatus": obj.get("checkStatus"),
            "sanctionRecord": EmailSanctionRecordM.from_dict(obj["sanctionRecord"]) if obj.get("sanctionRecord") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.validation_api import ValidationApi


class TestValidationApi(unittest.TestCase):
    """ValidationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ValidationApi()

    def tearDown(self) -> None:
        pass

    def test_browser(self) -> None:
        """Test case for browser

        Perform a browser validation
        """
        pass

    def test_email(self) -> None:
        """Test case for email

        Perform an email validation
        """
        pass

    def test_ipaddress(self) -> None:
        """Test case for ipaddress

        Perform an ip address validation
        """
        pass

    def test_mobile(self) -> None:
        """Test case for mobile

        Perform a mobile validation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.sanctions_api import SanctionsApi


class TestSanctionsApi(unittest.TestCase):
    """SanctionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SanctionsApi()

    def tearDown(self) -> None:
        pass

    def test_aircraft(self) -> None:
        """Test case for aircraft

        Perform an aircraft sanctions check
        """
        pass

    def test_crypto_wallet(self) -> None:
        """Test case for crypto_wallet

        Perform a crypto wallet sanctions check
        """
        pass

    def test_entity(self) -> None:
        """Test case for entity

        Perform an entity sanctions check
        """
        pass

    def test_individual(self) -> None:
        """Test case for individual

        Perform an individual sanctions list check
        """
        pass

    def test_vessel(self) -> None:
        """Test case for vessel

        Perform a vessel sanctions check
        """
        pass


if __name__ == '__main__':
    unittest.main()
